@@ -13,7 +13,7 @@ describe 'openstack_extras::repo::debian::ubuntu' do
 
     let :paramclass_defaults do
       {
-        :release => 'stein'
+        :release => 'xena'
       }
     end
 
@@ -23,12 +23,12 @@ describe 'openstack_extras::repo::debian::ubuntu' do
 
     context 'with default parameters' do
       let :params do
-        default_params
+        {}
       end
 
       it { should contain_apt__source('ubuntu-cloud-archive').with(
         :location => 'http://ubuntu-cloud.archive.canonical.com/ubuntu',
-        :release  => 'trusty-updates/stein',
+        :release  => 'trusty-updates/xena',
         :repos    => 'main',
       )}
 
@@ -61,16 +61,17 @@ describe 'openstack_extras::repo::debian::ubuntu' do
       let :params do
         default_params.merge!({ :source_hash => {
                                    'local_mirror' => {
-                                       'location' => 'http://mymirror/ubuntu/',
-                                       'repos'    => 'main',
-                                       'release'  => 'trusty'
+                                     'location' => 'http://mymirror/ubuntu/',
+                                     'repos'    => 'main',
+                                     'release'  => 'trusty'
                                    },
                                    'puppetlabs' => {
-                                       'location'   => 'http://apt.puppetlabs.com',
-                                       'repos'      => 'main',
-                                       'release'    => 'trusty',
-                                       'key'        => '4BD6EC30',
-                                       'key_server' => 'pgp.mit.edu'
+                                     'location' => 'http://apt.puppetlabs.com',
+                                     'repos'    => 'main',
+                                     'release'  => 'trusty',
+                                     'key'      => {
+                                       'id' => '4BD6EC30', 'server' => 'pgp.mit.edu'
+                                     }
                                    }
                                 }
                               })
@@ -83,11 +84,10 @@ describe 'openstack_extras::repo::debian::ubuntu' do
       )}
 
       it { should contain_apt__source('puppetlabs').with(
-        :location   => 'http://apt.puppetlabs.com',
-        :release    => 'trusty',
-        :repos      => 'main',
-        :key        => '4BD6EC30',
-        :key_server => 'pgp.mit.edu'
+        :location => 'http://apt.puppetlabs.com',
+        :release  => 'trusty',
+        :repos    => 'main',
+        :key      => { 'id' => '4BD6EC30', 'server' => 'pgp.mit.edu' }
       )}
 
       it { should contain_exec('installing ubuntu-cloud-keyring') }
@@ -97,23 +97,23 @@ describe 'openstack_extras::repo::debian::ubuntu' do
       let :params do
         default_params.merge!({ :source_hash => {
                                    'local_mirror' => {
-                                       'location' => 'http://mymirror/ubuntu/',
-                                       'repos'    => 'main',
-                                       'release'  => 'trusty'
+                                     'location' => 'http://mymirror/ubuntu/',
+                                     'repos'    => 'main',
+                                     'release'  => 'trusty'
                                    }
                                  }
                              })
         default_params.merge!({ :source_defaults => {
-                                   'include_src' => 'true'
+                                   'include' => { 'src' => true }
                                 }
                               })
       end
 
       it { should contain_apt__source('local_mirror').with(
-        :include_src => 'true',
-        :location    => 'http://mymirror/ubuntu/',
-        :release     => 'trusty',
-        :repos       => 'main',
+        :include  => { 'src' => true },
+        :location => 'http://mymirror/ubuntu/',
+        :release  => 'trusty',
+        :repos    => 'main',
       )}
 
       it { should contain_exec('installing ubuntu-cloud-keyring') }
@@ -127,7 +127,7 @@ describe 'openstack_extras::repo::debian::ubuntu' do
 
       it { should contain_apt__source('ubuntu-cloud-archive').with(
         :location => 'http://mirror.dfw.rax.openstack.org/ubuntu-cloud-archive',
-        :release  => 'trusty-proposed/stein',
+        :release  => 'trusty-proposed/xena',
         :repos    => 'main',
       )}
     end
